@@ -8,13 +8,20 @@ Dialog::Dialog(QWidget *parent) :
 {
     ui->setupUi(this);
     ui->zipCodeEntry->setInputMethodHints(Qt::ImhDigitsOnly);
+	zipCode = new QString();
 }
 
 Dialog::~Dialog()
 {
     delete ui;
+	delete zipCode;
 }
 
 void Dialog::setZip(){
-    zipCode = QString(ui->zipCodeEntry->text());
+	*zipCode = QString(ui->zipCodeEntry->text());
+}
+
+
+QString* Dialog::getZip(){
+	return zipCode;
 }
