@@ -11,6 +11,7 @@ public:
 	GraphFrame(QString& title, QPixmap& graphPix);
 	~GraphFrame();
 	QVBoxLayout* getLayout();
+	void setPix(QPixmap& pix);
 
 private:
 	QVBoxLayout* layout;
@@ -18,8 +19,6 @@ private:
 	QLabel* graph;
 	QScrollArea* scrollArea;
 
-	void colorize(QLabel* label);
-
 };
 
 #endif // GRAPHFRAME_H
