@@ -4,38 +4,42 @@
 #include "mainwindow.h"
 
 
-StackedWindow::StackedWindow(QString& latlong, QString& wfo, QString& zcode,
-							 QString& offset, QPixmap &dayIcon, QString& dayURL,
-							 QPixmap &nightIcon, QString& nightURL, QWidget *parent) :
+StackedWindow::StackedWindow(QDomDocument *doc, QPixmap &dayIcon, int dayVar, QPixmap &nightIcon, int nightVar, QWidget *parent) :
     QMainWindow(parent),
     ui(new Ui::StackedWindow)
 {
     ui->setupUi(this);
+	this->doc = doc;
+	QDomElement docEle = doc->documentElement();
+	QDomNodeList days = docEle.elementsByTagName("day");
 
-	QString tempTitle("<b>Temperature and Wind Chill:"), precipTitle("<b>Precipitation and Humidity ");
-	QString rainTitle("<b>Rain Accumulation:</b>"), snowTitle("<b>Snow Accumulation:</b>");
+	QString tempTitle("<b>Temperature and Wind Chill: </b>"), precipTitle("<b>Precipitation and Humidity: </b> ");
+	QString rainTitle("<b>Rain Accumulation: </b>"), snowTitle("<b>Snow Accumulation: </b> ");
 	QPixmap tempPix(1600, 220);
-	/*delete this after we find out what the deal is with the zcode
-	  for now we just hard code maine because it works for some reason*/
-	QString zc("MEZ015");
-	this->zcode = &zc;// delete this line once we find a way to get the zcode
+
 
 	/*init block*/
 	bool needDay = false;
 	bool needNight = false;
-	this->latlong = new QString(latlong);
-	this->wfo = new QString(wfo);
-	this->offset = new QString(offset);
-//	this->zcode = new QString(zcode);
 	manager = new QNetworkAccessManager(this);
 	mapper = new QSignalMapper(this);
 	tempFrame = new GraphFrame(tempTitle, tempPix);
 	precipFrame = new GraphFrame(precipTitle, tempPix);
 	rainFrame = 0;
 	snowFrame = 0;
-	QString* tempSearch = new QString("http://forecast.weather.gov/wtf/meteograms/Plotter.php?" + *this->latlong + "&wfo=" + *this->wfo + "&zcode=" + *this->zcode + "&gset=20&gdiff=10&unit=0&tinfo=EY5&ahour=" + *this->offset +"&pcmd=100100000000000000000000000000000000000000000000&lg=en&indu=1!1!1&dd=0&bw=0&hrspan=48&pqpfhr=6");
-	QString* precipSearch = new QString("http://forecast.weather.gov/wtf/meteograms/Plotter.php?" + *this->latlong + "&wfo=" + *this->wfo + "&zcode=" + *this->zcode + "&gset=20&gdiff=10&unit=0&tinfo=EY5&ahour=" + *this->offset +"&pcmd=000000110000000000000000000000000000000000000000&lg=en&indu=1!1!1&dd=0&bw=0&hrspan=48&pqpfhr=6");
-	QString* searchParams[4] = {tempSearch, precipSearch, &dayURL, &nightURL};
+	QString dayURL(QUrl::fromPercentEncoding(days.at(dayVar).namedItem("icon").toElement().text().toStdString().c_str()));
+	QString nightURL(QUrl::fromPercentEncoding(days.at(nightVar).namedItem("icon").toElement().text().toStdString().c_str()));
+	QString tempSearch = QUrl::fromPercentEncoding(days.at(dayVar).namedItem("tempGraph").toElement().text().toStdString().c_str());
+	QString precipSearch = QUrl::fromPercentEncoding(days.at(dayVar).namedItem("precipGraph").toElement().text().toStdString().c_str());
+	QString* searchParams[4] = {&tempSearch, &precipSearch, &dayURL, &nightURL};
+
+	ui->day->setText(days.at(dayVar).namedItem("name").toElement().text());
+	ui->hi->setText(days.at(dayVar).namedItem("temp").toElement().text());
+	ui->lo->setText(days.at(nightVar).namedItem("temp").toElement().text());
+	ui->precip->setText("Precipitation: " + days.at(dayVar).namedItem("precipitation").toElement().text());
+	ui->dayForecast->setText(days.at(dayVar).namedItem("wordedForecast").toElement().text());
+	ui->nightForecast->setText(days.at(nightVar).namedItem("wordedForecast").toElement().text());
+	MainWindow::colorize(ui->label_3);
 
 	/*add the layouts to the ui*/
 	QVBoxLayout* layout = qobject_cast<QVBoxLayout*>(ui->frame->layout());
@@ -71,22 +75,34 @@ StackedWindow::StackedWindow(QString& latlong, QString& wfo, QString& zcode,
     }
 
 
+
+
+	if(ui->dayForecast->text().contains("ain") || ui->nightForecast->text().contains("ain")){
+		rainFrame = new GraphFrame(rainTitle, tempPix);
+		layout->addLayout(rainFrame->getLayout());
+		QNetworkReply* reply = manager->get(QNetworkRequest(QUrl(QUrl::fromPercentEncoding(days.at(dayVar).namedItem("rainGraph").toElement().text().toStdString().c_str()))));
+		connect(reply, SIGNAL(finished()), this, SLOT(addRainGraph()));
+	}
+
+	if(ui->dayForecast->text().contains("now") || ui->nightForecast->text().contains("now")){
+		snowFrame = new GraphFrame(snowTitle, tempPix);
+		layout->addLayout(snowFrame->getLayout());
+		QNetworkReply* reply = manager->get(QNetworkRequest(QUrl(QUrl::fromPercentEncoding(days.at(dayVar).namedItem("snowGraph").toElement().text().toStdString().c_str()))));
+		connect(reply, SIGNAL(finished()), this, SLOT(addSnowGraph()));
+	}
+
+
 }
 
 StackedWindow::~StackedWindow()
 {
     delete ui;
-    delete manager;
-    delete mapper;
+	delete manager;
+	delete mapper;
 	delete rainFrame;
 	delete snowFrame;
 	delete tempFrame;
 	delete precipFrame;
-
-	delete latlong;
-	delete wfo;
-	delete offset;
-//	delete zcode;
 }
 
 
@@ -106,27 +122,6 @@ void StackedWindow::setIcons(int mapping){
 }
 
 
-void StackedWindow::setInfo(QString &day, QString &hi, QString &lo, QString &precip, QString &dayFor, QString &nightFor){
-    ui->day->setText(day);
-    ui->hi->setText(hi);
-    ui->lo->setText(lo);
-    ui->precip->setText(precip);
-    ui->dayForecast->setText(dayFor);
-    ui->nightForecast->setText(nightFor);
-	MainWindow::colorize(ui->label_3);
-
-	if(dayFor.contains("ain") || nightFor.contains("ain")){
-		QNetworkReply* reply = manager->get(QNetworkRequest(QUrl("http://forecast.weather.gov/wtf/meteograms/Plotter.php?" + *latlong + "&wfo=" + *wfo + "&zcode=MEZ015&gset=20&gdiff=10&unit=0&tinfo=EY5&ahour=" + *offset +"&pcmd=000000000100000000000000000000000000000000000000&lg=en&indu=1!1!1&dd=0&bw=0&hrspan=48&pqpfhr=6")));
-		connect(reply, SIGNAL(finished()), this, SLOT(addRainGraph()));
-	}
-
-	if(dayFor.contains("now") || nightFor.contains("now")){
-		QNetworkReply* reply = manager->get(QNetworkRequest(QUrl("http://forecast.weather.gov/wtf/meteograms/Plotter.php?" + *latlong + "&wfo=" + *wfo + "&zcode=MEZ015&gset=20&gdiff=10&unit=0&tinfo=EY5&ahour=" + *offset +"&pcmd=000000000010000000000000000000000000000000000000&lg=en&indu=1!1!1&dd=0&bw=0&hrspan=48&pqpfhr=6")));
-		connect(reply, SIGNAL(finished()), this, SLOT(addSnowGraph()));
-	}
-
-}
-
 /**
   Slot to add the snow graph to this window.
   Called only if the forecast includes snow
@@ -135,11 +130,7 @@ void StackedWindow::addSnowGraph(){
 	QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
 	reply->deleteLater();
 	QPixmap pix; pix.loadFromData(reply->readAll());
-	QString str("<b>Snow Accumulation:</b>");
-	snowFrame = new GraphFrame(str, pix);
-
-	QVBoxLayout* layout = qobject_cast<QVBoxLayout*>(ui->frame->layout());
-	layout->addLayout(snowFrame->getLayout());
+	snowFrame->setPix(pix);
 }
 
 /**
@@ -150,11 +141,7 @@ void StackedWindow::addRainGraph(){
 	QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
 	reply->deleteLater();
 	QPixmap pix; pix.loadFromData(reply->readAll());
-	QString str("<b>Rain Accumulation:</b>");
-	rainFrame = new GraphFrame(str, pix);
-
-	QVBoxLayout* layout = qobject_cast<QVBoxLayout*>(ui->frame->layout());
-	layout->addLayout(rainFrame->getLayout());
+	rainFrame->setPix(pix);
 }
 
 
