@@ -9,6 +9,7 @@
 #include <QSignalMapper>
 #include <QPropertyAnimation>
 #include <QLabel>
+#include <QDomDocument>
 #include "graphframe.h"
 
 namespace Ui {
@@ -20,11 +21,9 @@ class StackedWindow : public QMainWindow
     Q_OBJECT
 
 public:
-	explicit StackedWindow(QString& latlong, QString& wso, QString& zcode,
-						   QString& offset, QPixmap& dayIcon, QString& dayURL,
-						   QPixmap& nightIcon, QString& nightURL, QWidget *parent = 0);
+	explicit StackedWindow(QDomDocument* doc, QPixmap& dayIcon, int dayVar, QPixmap& nightIcon, int nightVar, QWidget *parent = 0);
     ~StackedWindow();
-    void setInfo(QString &day, QString &hi, QString &lo, QString &precip, QString &dayFor, QString &nightFor);
+//    void setInfo(QString &day, QString &hi, QString &lo, QString &precip, QString &dayFor, QString &nightFor);
 
 
 protected:
@@ -38,11 +37,8 @@ private slots:
 private:
     Ui::StackedWindow *ui;
     QSignalMapper* mapper;
-    QNetworkAccessManager *manager;
-	QString* wfo;
-	QString* latlong;
-	QString* offset;
-	QString* zcode;
+	QNetworkAccessManager *manager;
+	QDomDocument *doc;
 	GraphFrame* tempFrame;
 	GraphFrame* precipFrame;
 	GraphFrame* snowFrame;
